@@ -1229,31 +1229,6 @@ get_object_list (ECalBackendSync *backend, EDataCal *cal,
 	return GNOME_Evolution_Calendar_Success;
 }
 
-ECalBackendSyncStatus
-get_timezone (ECalBackendSync *backend, EDataCal *cal,
-	      const gchar *tzid, gchar **object)
-{
-	ECalBackendExchange *cbex = E_CAL_BACKEND_EXCHANGE (backend);
-	icaltimezone *zone;
-	icalcomponent *vtzcomp;
-	gchar *ical_obj;
-
-	d(printf("ecbe_get_timezone(%p, %p, %s)\n", backend, cal, tzid));
-
-	zone = g_hash_table_lookup (cbex->priv->timezones, tzid);
-	if (!zone)
-		return GNOME_Evolution_Calendar_ObjectNotFound;
-
-	vtzcomp = icaltimezone_get_component (zone);
-	if (!vtzcomp)
-		return GNOME_Evolution_Calendar_OtherError;
-
-	ical_obj = icalcomponent_as_ical_string_r (vtzcomp);
-	*object = ical_obj;
-
-	return  GNOME_Evolution_Calendar_Success;
-}
-
 icaltimezone *
 e_cal_backend_exchange_get_default_time_zone (ECalBackendSync *backend)
 {
@@ -1896,6 +1871,66 @@ get_mime_type (const gchar *uri)
 	return mime_type;
 }
 
+/* copies attachments to the backend's attachment store and returns new list of attachment URLs */
+GSList *
+receive_attachments (ECalBackendExchange *cbex, ECalComponent *comp)
+{
+	GSList *attach_urls = NULL;
+	GSList *l, *attach_list = NULL;
+	const gchar *uid = NULL;
+
+	g_return_val_if_fail (cbex != NULL, NULL);
+	g_return_val_if_fail (comp != NULL, NULL);
+
+	if (!e_cal_component_has_attachments (comp))
+		return NULL;
+
+	e_cal_component_get_uid (comp, &uid);
+	g_return_val_if_fail (uid != NULL, NULL);
+
+	e_cal_component_get_attachment_list (comp, &attach_list);
+	for (l = attach_list; l; l = l->next) {
+		gchar *fname, *dest_url, *attach_file = NULL, *file_contents;
+		gint len = 0;
+
+		if (!strncmp ((gchar *)l->data, "file://", 7)) {
+			fname = g_filename_from_uri ((gchar *)l->data, NULL, NULL);
+			attach_file = fname;
+		} else {
+			const gchar *filename;
+
+			fname = (gchar *)(l->data);
+			filename = g_strrstr (fname, "/");
+			if (!filename) {
+				/*
+				 * some vcards contain e.g. ATTACH:CID:0fd601c67efb$ef66760d$_CDOEX
+				 * -> ignore instead of crashing
+				 */
+				continue;
+			}
+			attach_file = g_strdup_printf ("%s/%s-%s", cbex->priv->local_attachment_store, uid, filename + 1);
+		}
+
+		/* attach_file should be g_freed */
+		file_contents = get_attach_file_contents (fname, &len);
+		if (!file_contents) {
+			g_free (attach_file);
+			continue;
+		}
+
+		dest_url = save_attach_file (attach_file, file_contents, len);
+		g_free (attach_file);
+		g_free (file_contents);
+		if (!dest_url) {
+			continue;
+		}
+
+		attach_urls = g_slist_append (attach_urls, dest_url);
+	}
+
+	return attach_urls;
+}
+
 gchar *
 build_msg ( ECalBackendExchange *cbex, ECalComponent *comp, const gchar *subject, gchar **boundary)
 {
@@ -2099,11 +2134,19 @@ static icaltimezone *
 internal_get_timezone (ECalBackend *backend, const gchar *tzid)
 {
 	ECalBackendExchange *cbex = E_CAL_BACKEND_EXCHANGE (backend);
+	icaltimezone *zone;
 
-	if (!tzid)
-		return NULL;
+	g_return_val_if_fail (cbex != NULL, NULL);
+	g_return_val_if_fail (tzid != NULL, NULL);
 
-	return g_hash_table_lookup (cbex->priv->timezones, tzid);
+	/* search in backend's time zone cache */
+	zone = g_hash_table_lookup (cbex->priv->timezones, tzid);
+
+	/* if not found, chain up */
+	if (!zone && E_CAL_BACKEND_CLASS (parent_class)->internal_get_timezone)
+		zone = E_CAL_BACKEND_CLASS (parent_class)->internal_get_timezone (backend, tzid);
+
+	return zone;
 }
 
 icaltimezone *
@@ -2111,8 +2154,14 @@ e_cal_backend_exchange_lookup_timezone (const gchar *tzid,
 					gconstpointer custom,
 					GError **error)
 {
-	return internal_get_timezone (E_CAL_BACKEND ((ECalBackendExchange *)custom),
-				      tzid);
+	icaltimezone *zone = internal_get_timezone (E_CAL_BACKEND ((ECalBackendExchange *)custom), tzid);
+
+	/* The UTC timezone is a fallback, which is not supposed
+	   to be returned in call of e_cal_check_timezones, thus skip it */
+	if (zone && zone == icaltimezone_get_utc_timezone ())
+		zone = NULL;
+
+	return zone;
 }
 
 static void
@@ -2224,7 +2273,6 @@ class_init (ECalBackendExchangeClass *klass)
 	sync_class->get_default_object_sync = get_default_object;
 	sync_class->get_object_sync = get_object;
 	sync_class->get_object_list_sync = get_object_list;
-	sync_class->get_timezone_sync = get_timezone;
 	sync_class->add_timezone_sync = add_timezone;
 	sync_class->set_default_timezone_sync = set_default_timezone;
 	sync_class->get_freebusy_sync = get_freebusy;
